summaryrefslogtreecommitdiff
path: root/test-cli/test/tests/qwifi.py
diff options
context:
space:
mode:
authorHector Fernandez <hector@iatec.biz>2020-03-06 12:46:27 +0100
committerHector Fernandez <hector@iatec.biz>2020-03-06 12:46:27 +0100
commit9f07a57d89a927aa9b172c1bf20c7ab563658c73 (patch)
tree3691cb8d09862db185a628c7bb07df6dd50a64bb /test-cli/test/tests/qwifi.py
parent98d40cecc9818360984188755e455aa53933aab0 (diff)
downloadboard-9f07a57d89a927aa9b172c1bf20c7ab563658c73.zip
board-9f07a57d89a927aa9b172c1bf20c7ab563658c73.tar.gz
board-9f07a57d89a927aa9b172c1bf20c7ab563658c73.tar.bz2
Fixed multiple errors.
Diffstat (limited to 'test-cli/test/tests/qwifi.py')
-rw-r--r--test-cli/test/tests/qwifi.py14
1 files changed, 8 insertions, 6 deletions
diff --git a/test-cli/test/tests/qwifi.py b/test-cli/test/tests/qwifi.py
index 154dd52..2a5fa0c 100644
--- a/test-cli/test/tests/qwifi.py
+++ b/test-cli/test/tests/qwifi.py
@@ -9,14 +9,16 @@ class Qwifi(unittest.TestCase):
__bind = None
__OKBW = None
__port = None
+ params = None
- #varlist: sip, bind, OKBW, port
+ #varlist: serverip, bind, OKBW, port
def __init__(self, testname, testfunc, varlist):
+ self.params = varlist
super(Qwifi, self).__init__(testfunc)
- if "sip" in varlist:
- self.__sip = varlist["sip"]
+ if "serverip" in varlist:
+ self.__serverip = varlist["serverip"]
else:
- raise Exception('sip param inside Qwifi have been be defined')
+ raise Exception('serverip param inside Qwifi have been be defined')
if "OKBW" in varlist:
self.__OKBW = varlist["OKBW"]
else:
@@ -47,10 +49,10 @@ class Qwifi(unittest.TestCase):
if result:
# execute iperf command against the server
if self.__bind is None:
- p = sh.iperf("-c", self.__sip, "-x", "CMSV", "-n", self.__numbytestx, "-f", "m", "-p",
+ p = sh.iperf("-c", self.__serverip, "-x", "CMSV", "-n", self.__numbytestx, "-f", "m", "-p",
self.__port)
else:
- p = sh.iperf("-c", self.__sip, "-x", "CMSV", "-n", self.__numbytestx, "-f", "m", "-p",
+ p = sh.iperf("-c", self.__serverip, "-x", "CMSV", "-n", self.__numbytestx, "-f", "m", "-p",
self.__port, "-B", self.__bind)
# check if it was executed succesfully
if p.exit_code == 0: